# RealMan
An effort to create digital human looks and moves like a real person.

# Todo
1. to add some python code, let the project to be a python package.
2. to decide which open dataset to use for later coding.
3. to train a venilla CNN for 3D HPE task.